pub struct Config(/* private fields */);Expand description
Corresponds to s2n_config.
Implementations
Sourceimpl Config
impl Config
Sourcepub fn new() -> Config
pub fn new() -> Config
Returns a Config object with pre-defined defaults.
Use the Builder if custom configuration is desired.
Warning
The newly created Config will use the default security policy.
Consider changing this depending on your security and compatibility requirements
by using Builder and Builder::set_security_policy.
See the s2n-tls usage guide:
https://aws.github.io/s2n-tls/usage-guide/ch06-security-policies.html