Psk

Struct Psk 

pub struct Psk { /* private fields */ }
Psk represents an out-of-band pre-shared key.

If two peers already have some mechanism to securely exchange secrets, then they can use Psks to authenticate rather than certificates.

Implementations