TlsStream

Struct TlsStream 

pub struct TlsStream<S, C = Connection>{ /* private fields */ }

Implementations

Source

impl<S, C> TlsStream<S, C>

pub fn get_ref(&self) -> &S

Access a shared reference to the underlaying io stream

pub fn get_mut(&mut self) -> &mut S

Access the mutable reference to the underlaying io stream

pub fn poll_blinding( self: Pin<&mut TlsStream<S, C>>, ctx: &mut Context<'_>, ) -> Poll<Result<(), Error>>

Polls the blinding timer, if there is any.

s2n has a “blinding” functionality - when a bad behavior from the peer is detected, sleeps for 10-30 seconds before answering the client and closing the connection. This mitigates some timing side channels that could leak information about encrypted data. See the s2n_connection_set_blinding docs for more details.

For security reasons, to allow for blinding to correctly function, before dropping an s2n connection, you should wait until either poll_blinding or poll_shutdown (which calls poll_blinding internally) returns ready.

pub async fn apply_blinding(&mut self) -> Result<(), Error>